import styles from './MapItem.module.css';
import { Component, createSignal } from "solid-js";
import { Group, Map, User, api } from "../api";
import { showDialog, showMessageDialog } from "../state";
import { errorToString } from "../util";
import { BsTrash } from 'solid-icons/bs';

export interface StratTypeItem {
	group: Group,
	stratType: string,
	onDelete: (m: string) => void
}

const StratTypeItem: Component<StratTypeItem> = (props) => {

	const deleteStratType = async () => {
		showDialog({
			title: 'Remove strat type',
			text: 'Do you want to remove this strat type?',
			buttons: [
				{
					name: 'Remove',
					type: 'danger',
					action: async () => {
						try {
							await api().removeStratType(props.group.id, props.stratType);
							props.onDelete(props.stratType);
						} catch (e) {
							showMessageDialog('Failed to remove strat type', errorToString(e));
						}
					}
				},
				{
					name: 'Cancel',
					action: () => { }
				}
			]
		});
	};

	return (
		<div class={styles.stratType}>
			<div class={styles.stratTypeDetails}>
				<div class={styles.stratTypeName}>
					<span innerText={props.stratType} />
				</div>
				<div>
					<button onClick={deleteStratType}><BsTrash /></button>
				</div>
			</div>
		</div >
	)
}

export default StratTypeItem;
